@@ -7,15 +7,25 @@
  ***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -31,16 +41,6 @@
 
 /////////////////////////////////////////////////////////////////////////////
 
-const QString CEcaIAManager::DQ("\"");
-const Status  CEcaIAManager::Running(0);
-const Status  CEcaIAManager::NotStarted(1);
-const Status  CEcaIAManager::Stopped(2);
-const Status  CEcaIAManager::Finished(3);
-const Status  CEcaIAManager::NotReady(-1);
-const Status  CEcaIAManager::Error(-2);
-
-/////////////////////////////////////////////////////////////////////////////
-
 CEcaIAManager::CEcaIAManager()
 {
   nTimerIDFinished = 0;
@@ -79,27 +79,11 @@ CEcaIAManager::runningStatus() const
 
 /////////////////////////////////////////////////////////////////////////////
 
-bool
-CEcaIAManager::isValidChainsetup()
-{
-  command("cs-is-valid", false);
-  int nValid = EcaControler.last_integer();
-
-  if ( nValid == 0 ) {
-    return false;
-  }
-  return true;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 int
 CEcaIAManager::numberOfInputs()
 {
   command("ai-list", false);
-  std::vector<std::string> vstrList = EcaControler.last_string_list();
-
-  return vstrList.size();
+  return lastCountOfStringList();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -108,9 +92,7 @@ int
 CEcaIAManager::numberOfOutputs()
 {
   command("ao-list", false);
-  std::vector<std::string> vstrList = EcaControler.last_string_list();
-
-  return vstrList.size();
+  return lastCountOfStringList();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -200,13 +182,13 @@ CEcaIAManager::slotPause()
 /////////////////////////////////////////////////////////////////////////////
 
 void
-CEcaIAManager::slotSetMasterPosition(const QTime& Time)
+CEcaIAManager::slotSetMasterPosition(const QTime& time)
 {
   int nSec = 0;
 
-  nSec += Time.hour() * 3600;
-  nSec += Time.minute() * 60;
-  nSec += Time.second();
+  nSec += time.hour() * 3600;
+  nSec += time.minute() * 60;
+  nSec += time.second();
 
   slotSetMasterPosition(nSec);
 }
@@ -293,7 +275,7 @@ CEcaIAManager::slotMixdown(
   QValueVector<CTrackInf>::iterator it = vTrackChains.begin();
   while ( it != vTrackChains.end() ) {
     QFileInfo FileInfo((*it).strFileName);
-    if ( (*it).strFileName == "" ) {
+    if ( (*it).strFileName.isEmpty() ) {
       continue;
     } else if ( !FileInfo.exists() ) {
       continue;
@@ -353,18 +335,18 @@ CEcaIAManager::slotAddChain(const CTrackInf& TrackInfAdd)
 {
   // if no input or no output, not be added
   QFileInfo FileInfo(TrackInfAdd.strFileName);
-  if ( TrackInfAdd.strFileName == "" ) {
+  if ( TrackInfAdd.strFileName.isEmpty() ) {
     return;
   } else if ( (!TrackInfAdd.bRecPort && !FileInfo.exists() ) || 
               !CVoxStormGlobal::isSupportedFileType(TrackInfAdd.strFileName) ) {
     return;
   } else {
     if ( TrackInfAdd.bRecPort ) {
-      if ( TrackInfAdd.strInputDevice == "" ) {
+      if ( TrackInfAdd.strInputDevice.isEmpty() ) {
         return;
       }
     } else {
-      if ( TrackInfAdd.strOutputDevice == "" ) {
+      if ( TrackInfAdd.strOutputDevice.isEmpty() ) {
         return;
       }
     }
@@ -437,11 +419,9 @@ CEcaIAManager::slotRemoveChain(int nID)
 void 
 CEcaIAManager::slotRemoveAllChains()
 {
-  int nCount = vTrackChains.size();
-  int i;
-  for ( i = 0; i < nCount; i++ ) {
-    slotRemoveChain(i);
-  }
+  command("c-select-all");
+  command("c-remove");
+  vTrackChains.clear();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -519,7 +499,7 @@ CEcaIAManager::slotChangeFileName(
     return;
   }
 
-  if ( strFileName == "" ) { // removed file name
+  if ( strFileName.isEmpty() ) { // removed file name
     slotRemoveChain(nIndex);
   }
 
@@ -620,7 +600,7 @@ CEcaIAManager::slotToggleRec(const QString& strTrackName, bool bRec)
 void
 CEcaIAManager::slotChangeStartPosition(
                  const QString& strTrackName,
-                 const QTime& StartPosition)
+                 const QTime& startPosition)
 {
   int nIndex;
 
@@ -628,7 +608,7 @@ CEcaIAManager::slotChangeStartPosition(
     return;
   }
 
-  vTrackChains[nIndex].TimeStartPosition = StartPosition;
+  vTrackChains[nIndex].TimeStartPosition = startPosition;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -636,7 +616,7 @@ CEcaIAManager::slotChangeStartPosition(
 void
 CEcaIAManager::slotChangeOffset(
                  const QString& strTrackName,
-                 const QTime& Offset)
+                 const QTime& offset)
 {
   int nIndex;
 
@@ -644,7 +624,7 @@ CEcaIAManager::slotChangeOffset(
     return;
   }
 
-  vTrackChains[nIndex].TimeOffset = Offset;
+  vTrackChains[nIndex].TimeOffset = offset;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -652,7 +632,7 @@ CEcaIAManager::slotChangeOffset(
 void
 CEcaIAManager::slotChangeLength(
                  const QString& strTrackName,
-                 const QTime& Length)
+                 const QTime& length)
 {
   int nIndex;
 
@@ -660,7 +640,7 @@ CEcaIAManager::slotChangeLength(
     return;
   }
 
-  vTrackChains[nIndex].TimeLength = Length;
+  vTrackChains[nIndex].TimeLength = length;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -691,17 +671,6 @@ CEcaIAManager::getIndexByName(const QString& strTrackName) const
 
 /////////////////////////////////////////////////////////////////////////////
 
-inline void
-CEcaIAManager::command(const QString& strCommand, bool bOut)
-{
-  EcaControler.command(strCommand.ascii());
-  if ( bOut ) {
-    emit messageGenerated(strCommand + "\n");
-  }
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void
 CEcaIAManager::setIOToCurrentChainsetup(bool bRecord)
 {
@@ -732,7 +701,7 @@ CEcaIAManager::setIOToCurrentChainsetup(bool bRecord)
       }
 
       // setup output (file)
-      if ( vPrepareTrackChains[i].strFileName != "" ) {
+      if ( !vPrepareTrackChains[i].strFileName.isEmpty() ) {
         nResult = CVoxStormGlobal::findStringFromList(
                               vPrepareTrackChains[i].strFileName, 
                               strlOutputFiles);
@@ -744,7 +713,7 @@ CEcaIAManager::setIOToCurrentChainsetup(bool bRecord)
     } else {                                     // playback
       // setup input (file)
       QFileInfo FileInfo(vPrepareTrackChains[i].strFileName);
-      //      if ( vPrepareTrackChains[i].strFileName != "" ) {
+      //      if ( !vPrepareTrackChains[i].strFileName.isEmpty() ) {
       if ( FileInfo.exists() ) {
         nResult = CVoxStormGlobal::findStringFromList(
                               vPrepareTrackChains[i].strFileName,
@@ -882,7 +851,7 @@ CEcaIAManager::setMixdownIOToCurrentChainsetup(
   for ( i = 0; i < nChains; i++ ) {
     // setup input (file)
     QFileInfo FileInfo(vPrepareTrackChains[i].strFileName);
-    //      if ( vPrepareTrackChains[i].strFileName != "" ) {
+    //      if ( !vPrepareTrackChains[i].strFileName.isEmpty() ) {
     if ( FileInfo.exists() ) {
       nResult = CVoxStormGlobal::findStringFromList(
                               vPrepareTrackChains[i].strFileName,
@@ -970,32 +939,6 @@ CEcaIAManager::setMixdownIOToCurrentChainsetup(
 
 /////////////////////////////////////////////////////////////////////////////
 
-Status
-CEcaIAManager::engineStatus()
-{
-  command("engine-status", false);
-  QString strStatus = EcaControler.last_string().c_str();
-
-  if ( strStatus == "running" ) {
-    return Running;
-  }
-  if ( strStatus == "not started" ) {
-    return NotStarted;
-  }
-  if ( strStatus == "stopped" ) {
-    return Stopped;
-  }
-  if ( strStatus == "finished" ) {
-    return Finished;
-  }
-  if ( strStatus == "not ready" ) {
-    return NotReady;
-  }
-  return Error;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void
 CEcaIAManager::timerEvent(QTimerEvent* TimerEvent)
 {
@@ -1032,19 +975,19 @@ CEcaIAManager::writeEwf(int nIndex, const QString& strFileName)
   strBuffer += DQ + vTrackChains[nIndex].strFileName + DQ + "\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  QTime Time = vTrackChains[nIndex].TimeOffset;
+  QTime time = vTrackChains[nIndex].TimeOffset;
   strBuffer = "offset = ";
-  strBuffer += QString("%1").arg(Time.secsTo(Time)) + ".0\n";
+  strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  Time = vTrackChains[nIndex].TimeStartPosition;
+  time = vTrackChains[nIndex].TimeStartPosition;
   strBuffer = "start-position = ";
-  strBuffer += QString("%1").arg(Time.secsTo(Time)) + ".0\n";
+  strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  Time = vTrackChains[nIndex].TimeLength;
+  time = vTrackChains[nIndex].TimeLength;
   strBuffer = "length = ";
-  strBuffer += QString("%1").arg(Time.secsTo(Time)) + ".0\n";
+  strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
   strBuffer = "looping = false\n";
