@@ -68,6 +68,8 @@ struct SPreferences
   int                  iFrameSeconds;
   //! åκĹ֡
   QTime                timeSessionMax;
+  //! ߥץؤΥѥ
+  QString              strMixerPath;
 };
 
 
@@ -141,6 +143,8 @@ private:
   KIntNumInput    *IntNumInputFrameSeconds;
   //! åκĹ֤ꤹ뤿Υåȡ
   QTimeEdit       *TimeEditSessionMax;
+  //! ߥץѥꤹ뤿Υåȡ
+  WFileChooser    *FileChooserMixer;
 
 private slots:
   //! \brief ǥեȥȥå̾ΥǥåѹΥåȡ
