@@ -43,6 +43,7 @@
 WVoxBase::WVoxBase(QWidget *WidgetParent, const char *cName)
   : QVBox(WidgetParent, cName)
 {
+  nTimerIDProceed = 0;
   setupWidgets();
 }
 
@@ -54,6 +55,7 @@ WVoxBase::WVoxBase(
       const char*     cName)
   : QVBox(WidgetParent, cName)
 {
+  nTimerIDProceed = 0;
   setupWidgets();
   addTracks(nodBase);
 }
@@ -62,15 +64,17 @@ WVoxBase::WVoxBase(
 
 WVoxBase::~WVoxBase()
 {
+  killTimers();  // kill all timers
+
   if (vVoxTracks.empty() ) {
     return;
   }
-  int i, nTrack;
 
-  nTrack = vVoxTracks.size();
-  for ( i = 0; i < nTrack; i++ ) {
-    delete vVoxTracks[i];
-    vVoxTracks[i] = NULL;
+  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+  while ( it != vVoxTracks.end() ) {
+    delete (*it);
+    (*it) = NULL;
+    it++;
   }
 
   vVoxTracks.clear();
@@ -120,6 +124,7 @@ WVoxBase::addTrack(
                                   strTrackName,
                                   strDeviceIn,
                                   strDeviceOut,
+                                  timeMaxSessionLength, 
                                   VBoxTracks);
 
   SignalMapperPlayback->setMapping(VoxTrackNew, strTrackName);
@@ -181,7 +186,10 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
   int i;
   int nCount = nolTracks.count();
   for ( i = 0; i < nCount; i++ ) {
-    WVoxTrack *VoxTrackNew = new WVoxTrack(nolTracks.item(i), VBoxTracks);
+    WVoxTrack *VoxTrackNew = new WVoxTrack(
+                                   nolTracks.item(i), 
+                                   timeMaxSessionLength, 
+                                   VBoxTracks);
     QString strTrackName = VoxTrackNew->name();
 
     SignalMapperPlayback->setMapping(VoxTrackNew, strTrackName);
@@ -226,6 +234,8 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
             this, SLOT(slotSetScrollToAll(QObject*, int)));
 
+    VoxTrackNew->setMaxSessionLength(timeMaxSessionLength);
+
     vVoxTracks.push_back(VoxTrackNew);
     VoxTrackNew->show();
   }
@@ -408,6 +418,16 @@ WVoxBase::setupWidgets()
   LabelPosition->setBuddy(TimeEditPosition);
   TimeEditPosition->setDisplay(
       QTimeEdit::Minutes | QTimeEdit::Seconds);
+
+  LabelProceed = new QLabel("   Position (MM:SS)", WidgetMisc);
+  HBoxLayout->addWidget(LabelProceed);
+  TimeEditProceed = new QTimeEdit(WidgetMisc);
+  TimeEditProceed->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+  HBoxLayout->addWidget(TimeEditProceed);
+  LabelProceed->setBuddy(TimeEditProceed);
+  TimeEditProceed->setDisplay(
+      QTimeEdit::Minutes | QTimeEdit::Seconds);
+
   HBoxLayout->addStretch();
 
   QSplitter   *Splitter = new QSplitter(Vertical, VBoxBase);
@@ -496,6 +516,19 @@ WVoxBase::stateInDOM(QDomDocument* pDoc)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::setMaxSessionLength(const QTime& time)
+{
+  timeMaxSessionLength = time;
+  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+  while ( it != vVoxTracks.end() ) {
+    (*it)->setMaxSessionLength(time);
+    it++;
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxBase::resizeEvent(QResizeEvent* Event)
 {
@@ -511,6 +544,21 @@ WVoxBase::resizeEvent(QResizeEvent* Event)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::timerEvent(QTimerEvent* Event)
+{
+  if ( Event->timerId() == nTimerIDProceed ) {
+    timeProceed = timeProceed.addSecs(1);
+    TimeEditProceed->setTime(timeProceed);
+  } else if ( Event->timerId() == nTimerIDPausing ) {
+    timeProceed = timeProceed.addSecs(1);
+  }
+
+  QVBox::timerEvent(Event);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxBase::slotWriteConsoleMessage(const QString& strMessage)
 {
@@ -532,49 +580,71 @@ WVoxBase::slotChangeMessageTab(TabType type)
 /////////////////////////////////////////////////////////////////////////////
 
 void
-WVoxBase::slotSetEnabledWidgets(State state)
+WVoxBase::slotChangeState(State state)
 {
-  int i, nTracks;
+  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
 
-  nTracks = vVoxTracks.size();
   if ( state == Play ) {
-    for ( i = 0; i < nTracks; i++ ) {
-      vVoxTracks[i]->slotSetEnabledWidgets(
-                       WVoxTrack::Record |
-                       WVoxTrack::File |
-                       WVoxTrack::Remove |
-                       WVoxTrack::Device |
-                       WVoxTrack::StartPosition |
-                       WVoxTrack::Offset |
-                       WVoxTrack::Length,
-                       false);
+    while ( it != vVoxTracks.end() ) {
+      (*it)->slotSetEnabledWidgets(
+               WVoxTrack::Record |
+               WVoxTrack::File |
+               WVoxTrack::Remove |
+               WVoxTrack::Device |
+               WVoxTrack::StartPosition |
+               WVoxTrack::Offset |
+               WVoxTrack::Length,
+               false);
+      it++;
+    }
+    if ( nTimerIDProceed == 0 && nTimerIDPausing != 0 ) {  // in pausing
+      nTimerIDProceed = nTimerIDPausing;
+      nTimerIDPausing = 0;
+    } else {
+      timeProceed = TimeEditPosition->time();
+      TimeEditProceed->show();
+      LabelProceed->show();
+      nTimerIDProceed = startTimer(1000); // 1 second timer
+      nTimerIDPausing = 0;
     }
   } else if ( state == Pause ) {
-    for ( i = 0; i < nTracks; i++ ) {
-      vVoxTracks[i]->slotSetEnabledWidgets(WVoxTrack::Record |
-                       WVoxTrack::File |
-                       WVoxTrack::Remove |
-                       WVoxTrack::Device,
-                       true);
-      vVoxTracks[i]->slotSetEnabledWidgets(WVoxTrack::Record |
-                       WVoxTrack::StartPosition |
-                       WVoxTrack::Offset |
-                       WVoxTrack::Length,
-                       false);
+    while ( it != vVoxTracks.end() ) {
+      (*it)->slotSetEnabledWidgets(
+               WVoxTrack::Record |
+               WVoxTrack::File |
+               WVoxTrack::Remove |
+               WVoxTrack::Device,
+              true);
+      (*it)->slotSetEnabledWidgets(
+               WVoxTrack::Record |
+               WVoxTrack::StartPosition |
+               WVoxTrack::Offset |
+               WVoxTrack::Length,
+               false);
+      it++;
     }
+    nTimerIDPausing = nTimerIDProceed;
+    nTimerIDProceed = 0;
   } else if ( state == Stop ) {
-    for ( i = 0; i < nTracks; i++ ) {
-      vVoxTracks[i]->slotSetEnabledWidgets(
-                       WVoxTrack::Record |
-                       WVoxTrack::File |
-                       WVoxTrack::Remove |
-                       WVoxTrack::Device |
-                       WVoxTrack::StartPosition |
-                       WVoxTrack::Offset |
-                       WVoxTrack::Length,
-                       true);
+    TimeEditProceed->hide();
+    LabelProceed->hide();
+    killTimer(nTimerIDProceed);
+    nTimerIDProceed = 0;
+    nTimerIDPausing = 0;
+    timeProceed = TimeEditPosition->time();
+    while ( it != vVoxTracks.end() ) {
+      (*it)->slotSetEnabledWidgets(
+               WVoxTrack::Record |
+               WVoxTrack::File |
+               WVoxTrack::Remove |
+               WVoxTrack::Device |
+               WVoxTrack::StartPosition |
+               WVoxTrack::Offset |
+               WVoxTrack::Length,
+               true);
+      it++;
     }
-  }    
+  }
 }
 
 /////////////////////////////////////////////////////////////////////////////
