@@ -40,6 +40,7 @@
 #include <kstatusbar.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <kprocess.h>
 #include <qpopupmenu.h>
 #include "wvoxstorm.h"
 #include "wmixdowndialog.h"
@@ -131,6 +132,8 @@ WVoxStorm::initialize()
           VoxBase, SLOT(slotWriteConsoleMessage(const QString&)));
 
   pDocVox = NULL;
+
+  applyPreferences();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -172,6 +175,7 @@ WVoxStorm::readConfigurationFile()
   QTime timeTmp;
   preferences.timeSessionMax = 
     timeTmp.addSecs(Config->readNumEntry("SessionMaxSecs", 1000));
+  preferences.strMixerPath = Config->readEntry("MixerPath", "");
   // <<<<---- setting for preferences member
 
   // ---->>>> setting for Mainwindow
@@ -226,6 +230,7 @@ WVoxStorm::writeConfigurationFile()
   QTime timeTmp;
   Config->writeEntry("SessionMaxSecs", 
                      timeTmp.secsTo(preferences.timeSessionMax));
+  Config->writeEntry("MixerPath", preferences.strMixerPath);
   // <<<<---- setting for Mainwindow
 
   // ---->>>> setting for Mainwindow
@@ -242,6 +247,14 @@ WVoxStorm::writeConfigurationFile()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxStorm::applyPreferences()
+{
+  VoxBase->setMaxSessionLength(preferences.timeSessionMax);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxStorm::setupActions()
 {
@@ -388,6 +401,22 @@ WVoxStorm::setupActions()
 
   menuBar()->insertItem(i18n("&Track"), PopupMenu);
 
+  PopupMenu = new QPopupMenu;
+  
+  toolBar()->insertLineSeparator();
+
+  Action = new KAction(i18n("Run &Mixer Program"), 
+                       "voxstorm_mixer", 
+                       0, 
+                       this, 
+                       SLOT(slotRunMixer()), 
+                       actionCollection(), 
+                       "Run Mixer Program");
+  Action->plug(PopupMenu);
+  Action->plug(toolBar());
+
+  menuBar()->insertItem(i18n("&Tools"), PopupMenu);
+
   PopupMenu = new QPopupMenu;
 
   toolBar()->insertLineSeparator();
@@ -760,7 +789,7 @@ WVoxStorm::slotPlay()
     ActionPlay->setEnabled(false);
     ToggleActionRec->setEnabled(false);
     ActionMixdown->setEnabled(false);
-    VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
+    VoxBase->slotChangeState(WVoxBase::Play);
     VoxBase->slotChangeMessageTab(WVoxBase::Console);
     EcaIAManager.slotPlay(ToggleActionRec->isChecked());
   } else {
@@ -784,7 +813,7 @@ WVoxStorm::slotPause()
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotPause();
-    VoxBase->slotSetEnabledWidgets(WVoxBase::Pause);
+    VoxBase->slotChangeState(WVoxBase::Pause);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -873,7 +902,7 @@ WVoxStorm::slotMixdown()
   ActionRewind->setEnabled(false);
   ActionForward->setEnabled(false);
   ActionMixdown->setEnabled(false);
-  VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
+  VoxBase->slotChangeState(WVoxBase::Play);
   VoxBase->slotChangeMessageTab(WVoxBase::Console);
   EcaIAManager.slotMixdown(
         mixdownDialog.mixesWithPlaying(), 
@@ -884,6 +913,17 @@ WVoxStorm::slotMixdown()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void
+WVoxStorm::slotRunMixer()
+{
+  KShellProcess process;
+
+  process << preferences.strMixerPath;
+  bool bStat = process.start(KProcess::DontCare);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxStorm::slotPreferences()
 {
@@ -891,6 +931,7 @@ WVoxStorm::slotPreferences()
   prefDialog.setFields(preferences);
   if ( prefDialog.exec() == QDialog::Accepted ) {
     preferences = prefDialog.fields();
+    applyPreferences();
   }
 
   writeConfigurationFile();
@@ -1094,7 +1135,7 @@ WVoxStorm::slotFinish()
   if ( ToggleActionRec->isChecked() ) {
     VoxBase->slotNotifySucceedInRecording();
   }
-  VoxBase->slotSetEnabledWidgets(WVoxBase::Stop);
+  VoxBase->slotChangeState(WVoxBase::Stop);
   ActionMixdown->setEnabled(true);
   ActionForward->setEnabled(true);
   ActionRewind->setEnabled(true);
