@@ -70,11 +70,6 @@ public:
   //! \brief ǥȥ饯
   virtual ~WVoxStorm();
 
-  //! \brief եξpreferencesɤ߹ࡣ
-  void readConfigurationFile();
-  //! \brief եpreferecesξ񤭹ࡣ
-  void writeConfigurationFile();
-
 protected:
   //! \brief ɥ׵Υ٥ȥϥɥ
   bool queryClose();
@@ -119,6 +114,13 @@ private:
   void setupActions();
   //! \brief ơСνԤ
   void setupStatusBar();
+  //! \brief եξpreferencesɤ߹ࡣ
+  void readConfigurationFile();
+  //! \brief եpreferecesξ񤭹ࡣ
+  void writeConfigurationFile();
+
+  //! \breif preferencesγͤŬѤ롣
+  void applyPreferences();
 
   //! \brief ѹ뤫ɤȽǤ롣
   bool isChanged() const;
@@ -175,6 +177,8 @@ private slots:
   void slotForward();
   //! \brief ֥ߥåפꤵ줿Υåȡ
   void slotMixdown();
+  //! \brief ֥ߥץ൯ưפꤵ줿Υåȡ
+  void slotRunMixer();
   //! \brief פꤵ줿Υåȡ
   void slotPreferences();
   //! \brief ֥󥿥饯ƥ֥⡼ɡפꤵ줿Υåȡ
