@@ -53,35 +53,38 @@ unsigned int WVoxTrack::Length(0x80);
 WVoxTrack::WVoxTrack(const QString& strName,
                      const QString& strDeviceIn,
                      const QString& strDeviceOut,
+                     const QTime&   timeMaxSession, 
                      QWidget*       WidgetParent,
                      const char*    cName)
   : QWidget(WidgetParent, cName)
 {
   strInputDevice = strDeviceIn;
   strOutputDevice = strDeviceOut;
-  setupWidgets();
+  setupWidgets(timeMaxSession);
   LabelName->setText(strName);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
 WVoxTrack::WVoxTrack(const CTrackInf& trackInf,
+                     const QTime&     timeMaxSession, 
                      QWidget*         WidgetParent, 
                      const char*      cName)
   : QWidget(WidgetParent, cName)
 {
-  setupWidgets();
+  setupWidgets(timeMaxSession);
   setStateByTrackInf(trackInf);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
 WVoxTrack::WVoxTrack(const QDomNode& nodTrack,
+                     const QTime&    timeMaxSession, 
                      QWidget*        WidgetParent, 
                      const char*     cName)
   : QWidget(WidgetParent, cName)
 {
-  setupWidgets();
+  setupWidgets(timeMaxSession);
   setStateByDom(nodTrack);
 }
 
@@ -94,7 +97,7 @@ WVoxTrack::~WVoxTrack()
 /////////////////////////////////////////////////////////////////////////////
 
 void 
-WVoxTrack::setupWidgets()
+WVoxTrack::setupWidgets(const QTime& timeMaxSession)
 {
   // this has VBoxController
   QHBoxLayout* HBoxLayout = new QHBoxLayout(this);
@@ -160,7 +163,7 @@ WVoxTrack::setupWidgets()
   HBoxTop->setMaximumWidth(350);
   HBoxTop->setMinimumWidth(350);
 
-  Locator = new WSoundLocator(this);
+  Locator = new WSoundLocator(timeMaxSession, this);
   HBoxLayout->addWidget(Locator, 100);
   Locator->setBaseColor(QColor(0, 0, 0));
   Locator->setItemFaceColor(QColor(111, 109, 158));
@@ -624,6 +627,14 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::setMaxSessionLength(const QTime& time)
+{
+  Locator->setMaxSessionLength(time);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::scrollLocator(int x)
 {
@@ -667,12 +678,15 @@ WVoxTrack::slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled)
   }
   if ( unWidgets & StartPosition ) {
     PopupMenu->setItemEnabled(nMenuIDStartPosition, bEnabled);
+    Locator->setEnabled(bEnabled);
   }
   if ( unWidgets & Offset ) {
     PopupMenu->setItemEnabled(nMenuIDOffset, bEnabled);
+    Locator->setEnabled(bEnabled);
   }
   if ( unWidgets & Length ) {
     PopupMenu->setItemEnabled(nMenuIDLength, bEnabled);
+    Locator->setEnabled(bEnabled);
   }
 }
 
